'use client'
import RecordAudio from "@/feature/messenger/components/ui/buttons/RecordAudio";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { useState } from "react";
import { FaMicrophone } from "react-icons/fa";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { Button, Tooltip } from "@nextui-org/react";
import { useTranslation } from "@/hooks/useTranslation";
import useResponsiveBtn from "@/feature/messenger/hooks/useReponsiveBtn";

export default function RecordAudioButton() {

    const handleOpenRecordVoice = useHandleConversationStore(state => state.actions.handleOpenRecordVoice);
    const agentPermissions = useConfigChatStore(state => state.permisions);
    const [recordAudio, setRecordAudio] = useState(false);
    const { trans } = useTranslation();
    const { responsiveButtonFooter, responsiveIconButtonFooter } = useResponsiveBtn();

    const handleEnableRecord = () => {
        setRecordAudio(true);
        handleOpenRecordVoice();
    }

    const handleClearRecord = () => {
        setRecordAudio(false);
        handleOpenRecordVoice();
    }    

    const componentChangeRecord = () => {
        if (recordAudio) {
            return (
                <RecordAudio handleClearRecord={handleClearRecord} />
            )
        } else {
            return (
                <>
                    <Tooltip
                        placement="top"
                        content={trans('footer_content_chat_mic_button_title')}	
                        color="default"
                    >
                        <Button color="primary" radius="full" className={responsiveButtonFooter} variant="flat" onClick={handleEnableRecord}>
                            <FaMicrophone size={14} className={responsiveIconButtonFooter} />
                        </Button> 
                    </Tooltip>
                </>
            )
        }
    }

    if (agentPermissions.envia_voz) {
        return (
            <>
                {componentChangeRecord()}
            </>
        )
    } else {
        return (
            <></>
        );
    }
}